package com.ruoyi.system.service.columns.impl;

import java.util.List;

import com.ruoyi.system.domain.columns.YjPracticeMoments;
import com.ruoyi.system.mapper.colums.YjPracticeMomentsMapper;
import com.ruoyi.system.service.columns.IYjPracticeMomentsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-10-29
 */
@Service
public class YjPracticeMomentsServiceImpl implements IYjPracticeMomentsService
{
    @Autowired
    private YjPracticeMomentsMapper yjPracticeMomentsMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public YjPracticeMoments selectYjPracticeMomentsById(String id)
    {
        return yjPracticeMomentsMapper.selectYjPracticeMomentsById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param yjPracticeMoments 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<YjPracticeMoments> selectYjPracticeMomentsList(YjPracticeMoments yjPracticeMoments)
    {
        return yjPracticeMomentsMapper.selectYjPracticeMomentsList(yjPracticeMoments);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param yjPracticeMoments 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertYjPracticeMoments(YjPracticeMoments yjPracticeMoments)
    {
        return yjPracticeMomentsMapper.insertYjPracticeMoments(yjPracticeMoments);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param yjPracticeMoments 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateYjPracticeMoments(YjPracticeMoments yjPracticeMoments)
    {
        return yjPracticeMomentsMapper.updateYjPracticeMoments(yjPracticeMoments);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteYjPracticeMomentsByIds(String[] ids)
    {
        return yjPracticeMomentsMapper.deleteYjPracticeMomentsByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteYjPracticeMomentsById(String id)
    {
        return yjPracticeMomentsMapper.deleteYjPracticeMomentsById(id);
    }
}
