package com.ruoyi.web.controller.columns;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.columns.YjPracticeMoments;
import com.ruoyi.system.service.columns.IYjPracticeMomentsService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 * 
 * @author ruoyi
 * @date 2025-10-29
 */
@RestController
@RequestMapping("/system/moments")
public class YjPracticeMomentsController extends BaseController
{
    @Autowired
    private IYjPracticeMomentsService yjPracticeMomentsService;

    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:moments:list')")
    @GetMapping("/list")
    public TableDataInfo list(YjPracticeMoments yjPracticeMoments)
    {
        startPage();
        yjPracticeMoments.setTenantId(SecurityUtils.getLoginUser().getNowTenantId());
        List<YjPracticeMoments> list = yjPracticeMomentsService.selectYjPracticeMomentsList(yjPracticeMoments);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:moments:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, YjPracticeMoments yjPracticeMoments) throws IOException {
        List<YjPracticeMoments> list = yjPracticeMomentsService.selectYjPracticeMomentsList(yjPracticeMoments);
        ExcelUtil<YjPracticeMoments> util = new ExcelUtil<YjPracticeMoments>(YjPracticeMoments.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:moments:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return AjaxResult.success(yjPracticeMomentsService.selectYjPracticeMomentsById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:moments:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody YjPracticeMoments yjPracticeMoments)
    {

        yjPracticeMoments.setId(IdWorker.get32UUID());
        return toAjax(yjPracticeMomentsService.insertYjPracticeMoments(yjPracticeMoments));
    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:moments:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody YjPracticeMoments yjPracticeMoments)
    {
        return toAjax(yjPracticeMomentsService.updateYjPracticeMoments(yjPracticeMoments));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:moments:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(yjPracticeMomentsService.deleteYjPracticeMomentsByIds(ids));
    }
}
